@@ -19,9 +19,10 @@
 
 void shrink(gsl_vector *v, double sigma);
 void group_shrink_general(gsl_vector* v, int *group_split, int*group_split_length);
-void logistic_grad(gsl_vector* v);
+void lasso_grad(gsl_matrix* A,gsl_vector* b,gsl_vector*x,gsl_vector* Ax,gsl_vector*w);
+void logistic_grad(gsl_matrix* A,gsl_vector* b,gsl_vector*x,gsl_vector* Ax,gsl_vector*w);
 void read_matrix(double* X, gsl_matrix* Y, int n, int p, int trans);
-void logistic_multi_grad(gsl_matrix* X, gsl_matrix* Y, gsl_matrix* W, gsl_matrix* W_temp);
+void logistic_multi_grad(gsl_matrix* X, gsl_matrix* Y, gsl_matrix* W, gsl_matrix* W_temp,gsl_matrix* G);
 void gsl_matrix_col_scale(gsl_matrix *X);
 void shrink_matrix(gsl_matrix *v, double sigma);
 void shrink_column_matrix(gsl_matrix *v);
@@ -29,7 +30,9 @@ void shrink_group_matrix_general(gsl_matrix *v,int *group_split, int*group_split
 void gsl_matrix_exp(gsl_matrix* X);
 void gsl_vector_log(gsl_vector* v);
 double gsl_matrix_Fnorm(gsl_matrix* X);
-
+void ising_grad(gsl_matrix* X,gsl_matrix*W,gsl_matrix*G);
+void potts_grad(gsl_matrix* X,gsl_matrix*W,gsl_matrix*G,int *group_split, int*group_split_length);
+void shrink_block_matrix_general(gsl_matrix *v,int *group_split, int*group_split_length);
 #endif
 
 
